Modules
- albers_
equal_ area - ellipsoid
- identity_
projection - lambert_
azimuthal_ equal_ area - lambert_
conic_ conformal - popvis_
pseudo_ mercator - stereographic
- transverse_
mercator
Structs
- Ellipsoid
- Ellipsoid, a simple approximation of the earth’s shape used in most
Projections
Traits
- DbContstruct
- Projection
- Two-dimensional coordinate operation
- Pseudo
Serialize
Functions
- custom_
projection - Try to construct a projection for a specific method code with a getter that provides the parameter values.