Ellipsoid

Struct Ellipsoid 

pub struct Ellipsoid {
    pub a: f64,
    pub b: f64,
    pub f: f64,
    pub e: f64,
    pub e_squared: f64,
}
Ellipsoid, a simple approximation of the earth’s shape used in most Projections

Fields

a: f64

semi-major axis

b: f64f: f64

flattening

e: f64

eccentricity

e_squared: f64

eccentricity squared

Implementations

Source

impl Ellipsoid

pub fn from_a_b(a: f64, b: f64) -> Self

Construct an ellipsoid from major and minor half axis.

pub fn from_a_f_inv(a: f64, f_inv: f64) -> Self

Construct an ellipsoid from major half axis and inverse flattening.

pub fn a(&self) -> f64

Get major half axis.

pub fn b(&self) -> f64

Get minor half axis.

pub fn f_inv(&self) -> f64

👎Deprecated since 0.8.0

Get inverse flattening. This method is deprecated as the inverse flattening is not defined for spheroids (division by zero).

pub fn f(&self) -> f64

Get flattening.

pub fn e(&self) -> f64

Get eccentricity.

pub fn e_squared(&self) -> f64

Get eccentricity squared.

pub fn e_2(&self) -> f64

Calculate secondary eccentricity.

pub fn rho(&self, lat: f64) -> f64

Calculate radius of curvature in the meridian, latitude in radians.

pub fn ny(&self, lat: f64) -> f64

Calculate radius of curvature in the prime vertical, latitude in radians.

pub fn rad_auth(&self) -> f64

Calculate radius of authalic sphere (sphere with the same surface area as the ellipsoid).

pub fn rad_conformal(&self, lat: f64) -> f64

Calculate radius of conformal sphere.

pub fn geocentric_to_deg(&self, x: f64, y: f64, z: f64) -> (f64, f64, f64)

Convert from geocentric position in meters to (longitude, latitude, height), geographic position in decimal degrees and ellipsoid height in meters.

pub fn deg_to_geocentric( &self, lon: f64, lat: f64, height: f64, ) -> (f64, f64, f64)

Convert from geographic position in decimal degrees and ellipsoid height in meters to (x, y, z), geocentric position in meters.

pub fn geocentric_to_rad(&self, x: f64, y: f64, z: f64) -> (f64, f64, f64)

Convert from geocentric position in meters to (longitude, latitude, height), geographic position in radians and ellipsoid height in meters.

pub fn rad_to_geocentric( &self, lon: f64, lat: f64, height: f64, ) -> (f64, f64, f64)

Convert from geographic position in radians and ellipsoid height in meters to (x, y, z), geocentric position in meters.